@@ -253,7 +253,6 @@ OC.L10N.register(
     "Saved" : "Bewaar",
     "Copy link" : "Kopieer skakel",
     "Dismiss" : "Ontslaan",
-    "Back" : "Terug",
     "Favorite" : "Gunsteling",
     "Remove from favorites" : "Verwyder uit gunstelinge",
     "Add to favorites" : "Voeg by gunstelinge",
@@ -261,6 +260,7 @@ OC.L10N.register(
     "Groups" : "Groepe",
     "Settings" : "Instellings",
     "Password protect" : "Beskerm met 'n wagwoord",
+    "Back" : "Terug",
     "Close" : "Sluit",
     "Reply" : "Antwoord",
     "Remove" : "Verwyder",
@@ -277,24 +277,13 @@ OC.L10N.register(
     "Search" : "Soek",
     "Share link" : "Deelskakel",
     "Enter a password" : "Gee ’n wagwoord",
+    "Send" : "Stuur",
     "Default" : "Verstek",
     "The password is wrong. Try again." : "Die wagwoord is verkeerd. Probeer weer.",
     "Android app" : "Android-toep",
     "iOS app" : "iOS-toep",
-    "Copy" : "Kopieer",
-    "Copied!" : "Gekopieer!",
-    "Not supported!" : "Word nie ondersteun nie!",
-    "Press ⌘-C to copy." : "Druk ⌘-C om te kopieer.",
-    "Press Ctrl-C to copy." : "Druk Ctrl-C om te kopieer.",
-    "Cancel" : "Kanselleer",
+    "Contacts" : "Kontakte",
     "Guests" : "Gaste",
-    "Change password" : "Verander wagwoord",
-    "Set password" : "Stel wagwoord",
-    "Rename" : "Hernoem",
-    "Send" : "Stuur",
-    "Share" : "Deel",
-    "Error while sharing" : "Fout terwyl deel",
-    "Favorited" : "As gunsteling ",
-    "Contacts" : "Kontakte"
+    "Cancel" : "Kanselleer"
 },
 "nplurals=2; plural=(n != 1);");
