@@ -1,6 +1,7 @@
 OC.L10N.register(
     "spreed",
     {
+    "a conversation" : "una conversación",
     "(Duration %s)" : "(Duración %s)",
     "You attended a call with {user1}" : "Tomaste una llamda con {user1}",
     "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados"],
@@ -10,11 +11,13 @@ OC.L10N.register(
     "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Tuviste una llamada con {user1}, {user2}, {user3}, {user4} y {user5}",
     "_%n other_::_%n others_" : ["%n otro","otros %n"],
     "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
+    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Te invitaron a una <strong>conversación</strong> o recibiste una <strong>llamada</strong>",
     "Talk" : "Hablar",
     "Guest" : "Invitado",
+    "- Spice up your messages with emojis from the emoji picker" : "Dale sabor a tus mensajes con emojis del selector de emoji",
+    "- Spice up your messages with emojis from the emoji picker {emoji}" : "Dale sabor a tus mensajes con emojis del selector de emoji {emoji}",
     "Talk to %s" : "Hablar con %s",
     "Join call" : "Unirse a la llamada",
-    "{user} wants to talk with you" : "{user} quiere hablar contigo",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
     "Conversations" : "Conversaciones",
@@ -39,9 +42,9 @@ OC.L10N.register(
     "Error" : "Error",
     "Blocked" : "Bloqueado",
     "Expired" : "Expirado",
+    "Shared secret" : "Secreto compartido",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Saved" : "Guardado",
-    "Shared secret" : "Secreto compartido",
     "STUN servers" : "Servidores STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
     "TURN server protocols" : "Protocolos del servidor TURN",
@@ -66,7 +69,6 @@ OC.L10N.register(
     "Enable video" : "Habilitar el video",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
-    "Back" : "Atrás",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
@@ -84,6 +86,7 @@ OC.L10N.register(
     "Circles" : "Círculos",
     "Settings" : "Configuraciones ",
     "Password protect" : "Proteger con contraseña",
+    "Back" : "Atrás",
     "Close" : "Cerrar",
     "Conversation name" : "Nombre de la conversación",
     "Reply" : "Responder",
@@ -116,6 +119,7 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Salir de pantalla completa (f)",
     "Fullscreen (f)" : "Pantalla completa (f)",
     "Grid view" : "Vista de cuadrícula",
+    "Send" : "Enviar",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
     "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
@@ -130,43 +134,15 @@ OC.L10N.register(
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
     "Android app" : "Aplicación Android",
     "iOS app" : "Aplicación iOS",
-    "New conversation …" : "Nueva conversación ...",
-    "Copy" : "Copiar",
-    "Copied!" : "¡Copiado!",
-    "Not supported!" : "¡No soportado!",
-    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
-    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
+    "{user} wants to talk with you" : "{user} quiere hablar contigo",
+    "No other people in this call" : "No hay más personas en esta llamada",
+    "Your screen" : "Tu pantalla",
+    "Contacts" : "Contactos",
+    "[Unknown user name]" : "[Nombre de usuario desconocido]",
+    "Guests" : "Invitados",
     "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
     "Password required" : "Contraseña requerida",
     "Cancel" : "Cancelar",
-    "Submit" : "Enviar",
-    "Guests" : "Invitados",
-    "Change password" : "Cambiar contraseña",
-    "Set password" : "Establecer contraseña",
-    "Rename" : "Renombrar",
-    "Link copied!" : "¡Liga copiada!",
-    "Conversation with {name}" : "Conversación con {name}",
-    "Error occurred while setting password" : "Se presentó un error al establecer al contraseña",
-    "No messages yet, start the conversation!" : "Aún no hay mensajes. ¡!Inicia la conversación!",
-    "New message …" : "Mensaje nuevo ...",
-    "Send" : "Enviar",
-    "Share" : "Compartir",
-    "[Unknown user name]" : "[Nombre de usuario desconocido]",
-    "Error occurred while sending message" : "Se presentó un error al enviar el mensaje",
-    "Error while sharing" : "Se presentó un error al compartir",
-    "No other people in this call" : "No hay más personas en esta llamada",
-    "Waiting for {participantName} to join the call …" : "Esperando a que {participantName} se una a la llamada…",
-    "WebRTC is not supported in your browser :-/" : "WebRTC no se encuentra soportado en tu navegador :-/",
-    "Waiting for camera and microphone permissions" : "Aguardando los permisos para la cámara y micrófono",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor da acceso a tu navegador para usar tu camara y micrófono poder usar esta aplicación. ",
-    "Share screen" : "Compartir la pantalla",
-    "No Camera" : "Sin cámara",
-    "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por tu navegador. ",
-    "Add participant …" : "Agregar participante ...",
-    "Favorited" : "Marcado como favorito",
-    "Your screen" : "Tu pantalla",
-    "{participantName}'s screen" : "Pantalla de {participantName}",
-    "Guest's screen" : "Pantalla del invitado",
-    "Contacts" : "Contactos"
+    "Submit" : "Enviar"
 },
 "nplurals=2; plural=(n != 1);");
