@@ -14,7 +14,6 @@ OC.L10N.register(
     "Guest" : "Invitado",
     "Talk to %s" : "Hablar con %s",
     "Join call" : "Unirse a la llamada",
-    "{user} wants to talk with you" : "{user} quiere hablar contigo",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
@@ -36,9 +35,9 @@ OC.L10N.register(
     "Pending" : "Pendiente",
     "Error" : "Error",
     "Blocked" : "Bloqueado",
+    "Shared secret" : "Secreto compartido",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Saved" : "Guardado",
-    "Shared secret" : "Secreto compartido",
     "STUN servers" : "Servidores STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
     "TURN server protocols" : "Protocolos del servidor TURN",
@@ -57,7 +56,6 @@ OC.L10N.register(
     "Enable video" : "Habilitar el video",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
-    "Back" : "Atrás",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
@@ -73,6 +71,7 @@ OC.L10N.register(
     "Circles" : "Círculos",
     "Settings" : "Configuraciones ",
     "Password protect" : "Proteger con contraseña",
+    "Back" : "Atrás",
     "Close" : "Cerrar",
     "Reply" : "Responder",
     "Remove" : "Eliminar",
@@ -100,6 +99,7 @@ OC.L10N.register(
     "Password protection" : "Protección con contraseña",
     "Enter a password" : "Ingresa una contraseña",
     "Grid view" : "Vista de cuadrícula",
+    "Send" : "Enviar",
     "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
@@ -112,36 +112,15 @@ OC.L10N.register(
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS",
-    "Copy" : "Copiar",
-    "Copied!" : "¡Copiado!",
-    "Not supported!" : "¡No soportado!",
-    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
-    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
+    "{user} wants to talk with you" : "{user} quiere hablar contigo",
+    "No other people in this call" : "No hay más personas en esta llamada",
+    "Your screen" : "Tu pantalla",
+    "Contacts" : "Contactos",
+    "[Unknown user name]" : "[Nombre de usuario desconocido]",
+    "Guests" : "Invitados",
     "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
     "Password required" : "Contraseña requerida",
     "Cancel" : "Cancelar",
-    "Submit" : "Enviar",
-    "Guests" : "Invitados",
-    "Change password" : "Cambiar contraseña",
-    "Set password" : "Establecer contraseña",
-    "Rename" : "Renombrar",
-    "No messages yet, start the conversation!" : "Aún no hay mensajes. ¡!Inicia la conversación!",
-    "Send" : "Enviar",
-    "Share" : "Compartir",
-    "[Unknown user name]" : "[Nombre de usuario desconocido]",
-    "Error occurred while sending message" : "Se presentó un error al enviar el mensaje",
-    "Error while sharing" : "Se presentó un error al compartir",
-    "No other people in this call" : "No hay más personas en esta llamada",
-    "Waiting for {participantName} to join the call …" : "Esperando a que {participantName} se una a la llamada…",
-    "WebRTC is not supported in your browser :-/" : "WebRTC no se encuentra soportado en tu navegador :-/",
-    "Waiting for camera and microphone permissions" : "Aguardando los permisos para la cámara y micrófono",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor da acceso a tu navegador para usar tu camara y micrófono poder usar esta aplicación. ",
-    "Share screen" : "Compartir la pantalla",
-    "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por tu navegador. ",
-    "Favorited" : "Marcado como favorito",
-    "Your screen" : "Tu pantalla",
-    "{participantName}'s screen" : "Pantalla de {participantName}",
-    "Guest's screen" : "Pantalla del invitado",
-    "Contacts" : "Contactos"
+    "Submit" : "Enviar"
 },
 "nplurals=2; plural=(n != 1);");
