@@ -1,7 +1,9 @@
 OC.L10N.register(
     "spreed",
     {
+    "_%n guest_::_%n guests_" : ["%n külaline","%n külalist"],
     "Talk" : "Talk",
+    "Guest" : "Külaline",
     "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
     "Limit to groups" : "Luba gruppidele",
     "Everyone" : "Igaüks",
@@ -20,11 +22,15 @@ OC.L10N.register(
     "Error" : "Viga",
     "Blocked" : "Blokeeritud",
     "Expired" : "Aegunud",
+    "Delete this server" : "Kustuta see server",
     "Saved" : "Salvestatud",
+    "UDP and TCP" : "UDP ja TCP",
+    "UDP only" : "Ainult UDP",
+    "TCP only" : "Ainult TCP",
     "Copy link" : "Kopeeri link",
     "Dismiss" : "Jäta vahele",
-    "Back" : "Tagasi",
     "Screensharing requires the page to be loaded through HTTPS." : "Ekraanijagamiseks tuleb leht laadida üle HTTPS protokolli.",
+    "You" : "Sina",
     "Favorite" : "Lemmik",
     "Remove from favorites" : "Eemalda lemmikutest",
     "Add to favorites" : "Lisa lemmikutesse",
@@ -32,6 +38,7 @@ OC.L10N.register(
     "Groups" : "Grupid",
     "Settings" : "Seaded",
     "Password protect" : "Parooliga kaitsmine",
+    "Back" : "Tagasi",
     "Close" : "Sulge",
     "Reply" : "Vasta",
     "Remove" : "Eemalda",
@@ -40,6 +47,7 @@ OC.L10N.register(
     "Enabled" : "Lubatud",
     "Save" : "Salvesta",
     "Password" : "Parool",
+    "API token" : "API kood",
     "Login" : "Logi sisse",
     "Nickname" : "Hüüdnimi",
     "Client ID" : "Kliendi ID",
@@ -54,22 +62,12 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
     "Grid view" : "Ruudustikvaade",
+    "Send" : "Saada",
     "Default" : "Vaikeväärtus",
     "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
     "Android app" : "Androidi rakendus",
     "iOS app" : "iOS-i rakendus",
-    "Copy" : "Kopeeri",
-    "Copied!" : "Kopeeritud!",
-    "Not supported!" : "Pole toetatud!",
-    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘+C.",
-    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl+C.",
-    "Cancel" : "Loobu",
-    "Change password" : "Muuda parooli",
-    "Rename" : "Nimeta ümber",
-    "Send" : "Saada",
-    "Share" : "Jaga",
-    "Error while sharing" : "Viga jagamisel",
-    "Favorited" : "Lemmikud",
-    "Contacts" : "Kontaktid"
+    "Contacts" : "Kontaktid",
+    "Cancel" : "Loobu"
 },
 "nplurals=2; plural=(n != 1);");
