@@ -267,7 +267,6 @@ OC.L10N.register(
     "You can invite others in the participant tab of the sidebar" : "شما می‌توانید دیگران را از زبانه اعضا در نوارکناری دعوت کنید",
     "Share this link to invite others!" : "این پیوند را به اشتراک بگذارید تا دیگران را دعوت کنید!",
     "Dismiss" : "پنهان کن",
-    "Back" : "بازگشت",
     "You" : "شما",
     "Drop your files to upload" : "برای بارگذاری، پرونده‌ها را اینجا رها کنید",
     "Favorite" : "برگزیده",
@@ -282,6 +281,7 @@ OC.L10N.register(
     "Create a new group conversation" : "ساخت گفتگوی گروهی جدید",
     "Password protect" : "نگهداری کردن رمز عبور",
     "Add participants" : "افزودن عضو",
+    "Back" : "بازگشت",
     "Close" : "بستن",
     "Conversation name" : "نام مکالمه",
     "Allow guests to join via link " : "مجاز بودن عضویت مهمان‌ها با پیوند",
@@ -305,7 +305,6 @@ OC.L10N.register(
     "Searching …" : "جستجوکردن …",
     "No results" : "نتیجه ای یافت نشد",
     "Add users or groups" : "کاربران یا گروه ها را اضافه کنید",
-    "Add participants to the conversation" : "افزودن عضو به گفتگو",
     "Participants" : "شركت كنندگان",
     "Edit" : "ویرایش",
     "Keyboard shortcuts" : "میان بر صفحه ی کلید",
@@ -316,6 +315,7 @@ OC.L10N.register(
     "Enter a password" : "یک گذرواژه وارد کنید",
     "Fullscreen (f)" : "تمام صفحه (f)",
     "Grid view" : "نمایش گرید",
+    "Send" : "ارسال",
     "Say hi to your friends and colleagues!" : "به رفقا و همدرس‌هایتان سلام کنید!",
     "Start a conversation" : "مکالمه را شروع کنید",
     "Join a conversation or start a new one!" : "عضو یک گفتگو شوید یا یک گفتگو جدید شروع کنید!",
@@ -324,26 +324,13 @@ OC.L10N.register(
     "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
     "Android app" : "اپ اندروید",
     "iOS app" : "اپ iOS",
-    "Projects" : "پروژه ها",
-    "Copy" : "کپی کردن",
-    "Copied!" : "کپی انجام شد!",
-    "Not supported!" : "پشتیبانی وجود ندارد!",
-    "Press ⌘-C to copy." : "برای کپی کردن از دکمه های C+⌘ استفاده نمایید",
-    "Press Ctrl-C to copy." : "برای کپی کردن از دکمه ctrl+c استفاده نمایید",
-    "Password required" : "رمز عبور لازم است",
-    "Cancel" : "لغو",
-    "Submit" : "ارسال",
+    "Contacts" : "مخاطبین",
+    "Add participants to the conversation" : "افزودن عضو به گفتگو",
     "Guests" : "میهمان ها",
     "Webinar" : "وبینار",
-    "Change password" : "تغییر گذر واژه",
-    "Set password" : "قراردادن رمز عبور",
-    "Rename" : "تغییرنام",
-    "Send" : "ارسال",
-    "Share" : "هم‌رسانی",
-    "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
-    "Add participant …" : "افزودن اعضا ...",
-    "Favorited" : "برگزیده شده",
-    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- مکالمات اکنون می توانند یک لابی داشته باشند. این به مدیران اجازه می دهد تا برای تهیه جلسه به چت بپیوندند و از قبل تماس بگیرند ، در حالی که کاربران و میهمانان باید منتظر بمانند.",
-    "Contacts" : "مخاطبین"
+    "Projects" : "پروژه ها",
+    "Password required" : "رمز عبور لازم است",
+    "Cancel" : "لغو",
+    "Submit" : "ارسال"
 },
 "nplurals=2; plural=(n > 1);");
