@@ -14,7 +14,6 @@ OC.L10N.register(
     "Saved" : "Gespäichert",
     "Copy link" : "Link kopéieren",
     "Dismiss" : "Ofbriechen",
-    "Back" : "Zeréck",
     "Favorite" : "Favorit",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
@@ -22,6 +21,7 @@ OC.L10N.register(
     "Groups" : "Gruppen",
     "Settings" : "Astellungen",
     "Password protect" : "Passwuertgeschützt",
+    "Back" : "Zeréck",
     "Close" : "Zoumaachen",
     "Reply" : "Äntwerten",
     "Remove" : "Läschen",
@@ -40,21 +40,12 @@ OC.L10N.register(
     "Share link" : "Link deelen",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
+    "Send" : "Schécken",
     "Default" : "Standard",
     "The password is wrong. Try again." : "Den Passwuert ass incorrect. Probeier ed nach eng keier.",
     "Android app" : "Android-App",
     "iOS app" : "iOS-App",
-    "Copied!" : "Kopéiert!",
-    "Not supported!" : "Nët ennerstëtzt!",
-    "Press ⌘-C to copy." : "Dréck ⌘-C fir ze kopéieren.",
-    "Press Ctrl-C to copy." : "Dréck CTRL-C fir ze kopéieren.",
-    "Cancel" : "Ofbriechen",
-    "Change password" : "Passwuert änneren",
-    "Rename" : "Ëmbenennen",
-    "Send" : "Schécken",
-    "Share" : "Deelen",
-    "Error while sharing" : "Feeler beim Deelen",
-    "Favorited" : "Favoriséiert",
-    "Contacts" : "Kontakter"
+    "Contacts" : "Kontakter",
+    "Cancel" : "Ofbriechen"
 },
 "nplurals=2; plural=(n != 1);");
