@@ -72,19 +72,29 @@ OC.L10N.register(
     "{actor} joined the conversation" : "{actor} prisijungė prie pokalbio",
     "You added {user}" : "Jūs pridėjote naudotoją {user}",
     "{actor} added you" : "{actor} jus pridėjo",
+    "An administrator added {user}" : "Administratorius pridėjo naudotoją {user}",
     "You left the conversation" : "Jūs išėjote iš pokalbio",
     "{actor} left the conversation" : "{actor} išėjo iš pokalbio",
     "{actor} removed {user}" : "{actor} pašalino naudotoją {user}",
     "You removed {user}" : "Jūs pašalinote naudotoją {user}",
     "{actor} removed you" : "{actor} jus pašalino",
+    "An administrator removed {user}" : "Administratorius pašalino naudotoją {user}",
     "{actor} promoted {user} to moderator" : "{actor} paaukštino naudotoją {user} į moderatorius",
     "You promoted {user} to moderator" : "Jūs paaukštinote naudotoją {user} į moderatorius",
     "{actor} promoted you to moderator" : "{actor} paaukštino jus į moderatorius",
     "{actor} demoted {user} from moderator" : "{actor} pažemino naudotoją {user} iš moderatorių",
     "You demoted {user} from moderator" : "Jūs pažeminote naudotoją {user} iš moderatorių",
     "{actor} demoted you from moderator" : "{actor} pažemino jus iš moderatorių",
+    "An administrator demoted you from moderator" : "Administratorius pažemino jus iš moderatorių",
+    "An administrator demoted {user} from moderator" : "Administratorius pažemino naudotoją {user} iš moderatorių",
     "{actor} shared a file which is no longer available" : "{actor} pradėjo bendrinti failą, kuris daugiau nebeprieinamas",
     "You shared a file which is no longer available" : "Jūs pradėjote bendrinti failą, kuris daugiau nebeprieinamas",
+    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} nustatė „Matterbridge“, kad sinchronizuotų šį pokalbį su kitais pokalbiais.",
+    "You set up Matterbridge to synchronize this conversation with other chats." : "Jūs nustatėte „Matterbridge“, kad sinchronizuotumėte šį pokalbį su kitais pokalbiais.",
+    "{actor} updated the Matterbridge configuration." : "{actor} atnaujino „Matterbridge“ konfigūraciją.",
+    "You updated the Matterbridge configuration." : "Jūs atnaujinote „Matterbridge“ konfigūraciją.",
+    "{actor} removed the Matterbridge configuration." : "{actor} pašalino „Matterbridge“ konfigūraciją.",
+    "You removed the Matterbridge configuration." : "Jūs pašalinote „Matterbridge“ konfigūraciją.",
     "%s (guest)" : "%s (svečias)",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Skambutis su %n svečiu (Trukmė {duration})","Skambutis su %n svečiais (Trukmė {duration})","Skambutis su %n svečių (Trukmė {duration})","Skambutis %n svečiu (Trukmė {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Skambutis su {user1} ir {user2} (Trukmė {duration})",
@@ -93,6 +103,7 @@ OC.L10N.register(
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Skambutis su {user1}, {user2}, {user3}, {user4} ir {user5} (Trukmė {duration})",
     "Talk to %s" : "Kalbėti su %s",
     "File is not shared, or shared but not with the user" : "Failas nėra bendrinamas arba yra bendrinamas, tačiau ne su naudotoju",
+    "Talk mentions" : "Paminėjimai pokalbiuose",
     "Write to conversation" : "Rašyti į pokalbį",
     "Writes event information into a conversation of your choice" : "Parašo apie įvykio informaciją į jūsų pasirinktą pokalbį",
     "%s invited you to a conversation." : "%s jus pakvietė į pokalbį.",
@@ -123,7 +134,6 @@ OC.L10N.register(
     "Join call" : "Prisijungti prie skambučio",
     "{user} invited you to a group conversation: {call}" : "{user} jus pakvietė į grupės pokalbį: {call}",
     "Answer call" : "Atsiliepti",
-    "{user} wants to talk with you" : "{user} nori su jumis pakalbėti",
     "Call back" : "Atskambinti",
     "You missed a call from {user}" : "Jūs praleidote skambutį nuo {user}",
     "A group call has started in {call}" : "Grupės skambutis prasidėjo ties {call}",
@@ -139,7 +149,10 @@ OC.L10N.register(
     "Something unexpected happened." : "Nutiko kažkas netikėto.",
     "The URL is invalid." : "URL yra neteisingas.",
     "The email address is invalid." : "El. pašto adresas yra neteisingas.",
+    "The language is invalid." : "Neteisinga kalba.",
+    "The country is invalid." : "Neteisinga šalis.",
     "Something unexpected happened. Please try again later." : "Nutiko kažkas netikėto. Vėliau bandykite dar kartą.",
+    "There is no such account registered." : "Nėra tokios registruotos paskyros.",
     "Andorra" : "Andora",
     "United Arab Emirates" : "Jungtiniai Arabų Emyratai",
     "Afghanistan" : "Afganistanas",
@@ -179,7 +192,9 @@ OC.L10N.register(
     "Colombia" : "Kolumbija",
     "Costa Rica" : "Kosta Rika",
     "Cuba" : "Kuba",
+    "Christmas Island" : "Kalėdų sala",
     "Cyprus" : "Kipras",
+    "Czechia" : "Čekija",
     "Germany" : "Vokietija",
     "Djibouti" : "Džibutis",
     "Denmark" : "Danija",
@@ -194,11 +209,14 @@ OC.L10N.register(
     "Ethiopia" : "Etiopija",
     "Finland" : "Suomija",
     "Fiji" : "Fidžis",
+    "Falkland Islands (Malvinas)" : "Folklando (Malvinų) salos",
+    "Faroe Islands" : "Farerų salos",
     "France" : "Prancūzija",
     "Gabon" : "Gabonas",
     "Grenada" : "Grenada",
     "Georgia" : "Gruzija",
     "Ghana" : "Gana",
+    "Gibraltar" : "Gibraltaras",
     "Greenland" : "Grenlandija",
     "Gambia" : "Gambija",
     "Guinea" : "Gvinėja",
@@ -207,6 +225,7 @@ OC.L10N.register(
     "Guatemala" : "Gvatemala",
     "Guinea-Bissau" : "Bisau Gvinėja",
     "Guyana" : "Gajana",
+    "Hong Kong" : "Honkongas",
     "Honduras" : "Hondūras",
     "Croatia" : "Kroatija",
     "Haiti" : "Haitis",
@@ -241,6 +260,7 @@ OC.L10N.register(
     "Monaco" : "Monakas",
     "Montenegro" : "Juodkalnija",
     "Madagascar" : "Madagaskaras",
+    "Marshall Islands" : "Maršalo salos",
     "Mali" : "Malis",
     "Myanmar" : "Mianmaras",
     "Mongolia" : "Mongolija",
@@ -311,6 +331,7 @@ OC.L10N.register(
     "United States of America" : "Jungtinės Amerikos Valstijos",
     "Uruguay" : "Urugvajus",
     "Uzbekistan" : "Uzbekistanas",
+    "Viet Nam" : "Vietnamas",
     "Vanuatu" : "Vanuatu",
     "Yemen" : "Jemenas",
     "South Africa" : "Pietų Afrika",
@@ -350,14 +371,18 @@ OC.L10N.register(
     "Script" : "Scenarijus",
     "General settings" : "Bendri nustatymai",
     "Integration into other apps" : "Integracija į kitas programėles",
+    "Allow conversations on files" : "Leisti pokalbius failuose",
+    "Allow conversations on public shares for files" : "Leisti pokalbius viešai bendrinamuose failuose",
     "All messages" : "Visos žinutės",
     "@-mentions only" : "Tik @ paminėjimai",
     "Off" : "Išjungta",
+    "URL of this Nextcloud instance" : "Šio Nextcloud egzemplioriaus URL",
     "E-mail of the user" : "Naudotojo el. paštas",
     "Language" : "Kalba",
     "Country" : "Šalis",
     "Status" : "Būsena",
     "Created at" : "Sukurta",
+    "Expires at" : "Baigia galioti",
     "Pending" : "Laukiantis",
     "Error" : "Klaida",
     "Blocked" : "Blokuota",
@@ -365,8 +390,12 @@ OC.L10N.register(
     "Expired" : "Nebegalioja",
     "The account could not be deleted. Please try again later." : "Nepavyko ištrinti paskyros. Vėliau bandykite dar kartą.",
     "_%n user_::_%n users_" : ["%n naudotojas","%n naudotojai","%n naudotojų","%n naudotojas"],
+    "Matterbridge integration" : "„Matterbridge“ integracija",
+    "Enable Matterbridge integration" : "Įjungti „Matterbridge“ integraciją",
     "Downloading …" : "Atsisiunčiama…",
     "Installed version: {version}" : "Įdiegta versija: {version}",
+    "SIP configuration" : "SIP konfigūracija",
+    "Phone number (Country)" : "Telefono numeris (Šalis)",
     "Delete this server" : "Ištrinti šį serverį",
     "Status: Checking connection" : "Būsena: Tikrinamas ryšys",
     "Error: Can not connect to server" : "Klaida: Nepavyksta prisijungti prie serverio",
@@ -412,6 +441,7 @@ OC.L10N.register(
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą. Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
     "Screensharing options" : "Ekrano bendrinimo parinktys",
     "Enable screensharing" : "Įjungti ekrano bendrinimą",
+    "Disable screenshare" : "Išjungti ekrano bendrinimą",
     "Screen sharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
@@ -419,6 +449,8 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
     "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
+    "Access to camera was denied" : "Prieiga prie kameros buvo uždrausta",
+    "Error while accessing camera" : "Klaida gaunant prieigą prie kameros",
     "You" : "Jūs",
     "Show screen" : "Rodyti ekraną",
     "Mute" : "Nutildyti",
@@ -463,6 +495,7 @@ OC.L10N.register(
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Šiuo metu laukiate laukimo salėje. Šio susitikimo pradžia yra suplanuota {startTime}",
     "Calls are not supported in your browser" : "Jūsų naršyklėje skambučiai yra nepalaikomi",
     "Access to microphone is only possible with HTTPS" : "Prieiga prie mikrofono yra įmanoma tik naudojant HTTPS",
+    "Access to microphone was denied" : "Prieiga prie mikrofono buvo uždrausta",
     "Error while accessing microphone" : "Klaida gaunant prieigą prie mikrofono",
     "Access to camera is only possible with HTTPS" : "Prieiga prie kameros yra įmanoma tik naudojant HTTPS",
     "Microphone" : "Mikrofonas",
@@ -499,8 +532,14 @@ OC.L10N.register(
     "Login" : "Prisijungti",
     "Nickname" : "Slapyvardis",
     "IRC channel" : "IRC kanalas",
+    "Use TLS" : "Naudoti TLS",
+    "Use SASL" : "Naudoti SASL",
     "Client ID" : "Kliento ID",
+    "XMPP/Jabber server URL" : "XMPP/Jabber serverio URL",
     "MUC server URL" : "MUC serverio URL",
+    "Jabber ID" : "Jabber ID",
+    "Channel" : "Kanalas",
+    "unknown state" : "nežinoma būsena",
     "moderator" : "moderatorius",
     "guest" : "svečias",
     "Participant settings" : "Dalyvio nustatymai",
@@ -512,6 +551,7 @@ OC.L10N.register(
     "Add circles" : "Pridėti ratus",
     "Searching …" : "Ieškoma…",
     "No results" : "Rezultatų nėra",
+    "Search for more users" : "Ieškoti daugiau naudotojų",
     "Add users or groups" : "Pridėti naudotojus ar grupes",
     "Add groups or circles" : "Pridėti grupes ar ratus",
     "Add other sources" : "Pridėti kitus šaltinius",
@@ -520,6 +560,7 @@ OC.L10N.register(
     "Chat" : "Pokalbis",
     "Display name: " : "Rodomas vardas: ",
     "Edit" : "Taisyti",
+    "Choose devices" : "Pasirinkti įrenginius",
     "Attachments folder" : "Priedų aplankas",
     "Keyboard shortcuts" : "Klavišų kombinacijos",
     "Search" : "Ieškoti",
@@ -537,6 +578,8 @@ OC.L10N.register(
     "Fullscreen (f)" : "Visas ekranas (f)",
     "Grid view" : "Tinklelio rodinys",
     "Send" : "Siųsti",
+    "Add more files" : "Pridėti daugiau failų",
+    "No unread mentions" : "Nėra neskaitytų paminėjimų",
     "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
     "Start a conversation" : "Pradėti pokalbį",
     "Message without mention" : "Rašyti be paminėjimo",
@@ -548,8 +591,10 @@ OC.L10N.register(
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Nextcloud Pokalbiai pilnai nepalaiko jūsų naudojamos naršyklės. Naudokite naujausią Mozilla Firefox, Microsoft Edge, Google Chrome ar Apple Safari versiją.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Pokalbiai buvo atnaujinti, įkelkite puslapį iš naujo",
     "Do not disturb" : "Netrukdyti",
+    "Away" : "Atsitraukęs",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud yra techninės priežiūros veiksenoje, įkelkite puslapį iš naujo",
     "Error while sharing file" : "Klaida bendrinant failą",
+    "Failed to join the conversation. Try to reload the page." : "Nepavyko prisijungti prie pokalbio. Pabandykite įkelti puslapį iš naujo.",
     "Sending signaling message has failed." : "Nepavyko išsiųsti signalinės žinutės.",
     "Establishing signaling connection is taking longer than expected …" : "Signalinio ryšio užmezgimas trunka ilgiau nei tikėtasi…",
     "Failed to establish signaling connection. Retrying …" : "Nepavyko užmegzti signalinio ryšio. Bandoma iš naujo…",
@@ -560,10 +605,10 @@ OC.L10N.register(
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tai užtrunka ilgiau, nei tikėtasi. Ar medijos leidimai jau yra suteikti (arba atmesti)? Jeigu taip, tuomet paleiskite savo naršyklę iš naujo, nes garsas ir vaizdas patiria nesėkmę",
     "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
     "Please move your setup to HTTPS" : "Perkelkite savo sąranką į HTTPS",
-    "Access to microphone & camera was denied" : "Prieiga prie mikrofono ir kameros buvo atmesta",
+    "Access to microphone & camera was denied" : "Prieiga prie mikrofono ir kameros buvo uždrausta",
     "WebRTC is not supported in your browser" : "Jūsų naršyklėje WebRTC nėra palaikoma",
     "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
-    "Error while accessing microphone & camera" : "Klaida, gaunant prieigą prie mikrofono ir kameros",
+    "Error while accessing microphone & camera" : "Klaida gaunant prieigą prie mikrofono ir kameros",
     "This conversation is password-protected" : "Šis pokalbis yra apsaugotas slaptažodžiu",
     "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
     "TURN server" : "TURN serveris",
@@ -573,6 +618,7 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
     "Android app" : "Android programėlė",
     "iOS app" : "iOS programėlė",
+    "{user} wants to talk with you" : "{user} nori su jumis pakalbėti",
     "No other people in this call" : "Šiame skambutyje nėra kitų žmonių",
     "Your screen" : "Jūsų ekranas",
     "Contacts" : "Adresatai",
