@@ -174,7 +174,6 @@ OC.L10N.register(
     "Dismiss" : "Hiq",
     "Mute audio" : "Mute audio",
     "Disable video" : "Çaktivizo video",
-    "Back" : "Prapa",
     "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
     "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
@@ -191,6 +190,7 @@ OC.L10N.register(
     "Circles" : "Rrethet",
     "Settings" : "Rregullimet",
     "Password protect" : "Mbroje me fjalëkalim",
+    "Back" : "Prapa",
     "Close" : "Mbylleni",
     "Conversation name" : "Emri i bisedës",
     "Camera" : "Kamera",
@@ -217,6 +217,7 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Enter a password" : "Fusni një fjalëkalim",
     "Grid view" : "Pamje galeri",
+    "Send" : "Dërgo",
     "Start a conversation" : "Filloni një bisedë",
     "Default" : "E paracaktuar",
     "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
@@ -229,32 +230,12 @@ OC.L10N.register(
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli.",
     "Android app" : "Aplikacion Android",
     "iOS app" : "Aplikacion iOS",
-    "Copy" : "Kopjo",
-    "Copied!" : "U kopjua!",
-    "Not supported!" : "Nuk mbështetet!",
-    "Press ⌘-C to copy." : "Shtyni ⌘-C që të kopjoni.",
-    "Press Ctrl-C to copy." : "Shtyp Ctrl-C për të kopjuar",
+    "No other people in this call" : "Jo njerëz të tjerë në këtë thirrje",
+    "Your screen" : "Ekrani juaj",
+    "Contacts" : "Kontaktet",
+    "Guests" : "Të ftuarit",
     "Password required" : "Kërkohet fjalëkalimi",
     "Cancel" : "Anulo",
-    "Submit" : "Dërgo",
-    "Guests" : "Të ftuarit",
-    "Change password" : "Ndryshoni fjalëkalimin",
-    "Set password" : "Vendos fjalëkalimin",
-    "Rename" : "Riemëroj",
-    "Send" : "Dërgo",
-    "Share" : "Shpërndaje",
-    "Error while sharing" : "Gabim gjatë ndarjes",
-    "No other people in this call" : "Jo njerëz të tjerë në këtë thirrje",
-    "Waiting for {participantName} to join the call …" : "Duke pritur për {participantName} që ti bashkohet telefonatës ...",
-    "WebRTC is not supported in your browser :-/" : "WebRTC nuk suportohet nga shfletuesi juaj :-/",
-    "Waiting for camera and microphone permissions" : "Duke pritur për autorizimin e kameras dhe mikrofonit ",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Ju lutemi, ti jepni akses browser-it tuaj për të përdorur kameran dhe mikrofonin në mënyrë që të përdorni këtë app.",
-    "Share screen" : "Ndaje ekranin",
-    "Screensharing is not supported by your browser." : "Ndarja e erkaneve nuk është e mbështetur nga shfletuesi juaj ",
-    "Favorited" : "U kalua e parapëlqyer",
-    "Your screen" : "Ekrani juaj",
-    "{participantName}'s screen" : "Ekrani i {participantName}",
-    "Guest's screen" : "Ekrani i të ftuarit",
-    "Contacts" : "Kontaktet"
+    "Submit" : "Dërgo"
 },
 "nplurals=2; plural=(n != 1);");
