@@ -117,7 +117,6 @@ OC.L10N.register(
     "Join call" : "Gå med i samtal",
     "{user} invited you to a group conversation: {call}" : "{user} bjöd in dig till en gruppkonversation: {call}",
     "Answer call" : "Svara på samtal",
-    "{user} wants to talk with you" : "{user} vill prata med dig",
     "Call back" : "Ring tillbaka",
     "You missed a call from {user}" : "Du missade ett samtal från {user}",
     "A group call has started in {call}" : "Ett gruppsamtal har startats i {call}",
@@ -426,6 +425,7 @@ OC.L10N.register(
     "Blocked" : "Blockerar",
     "Active" : "Aktiv",
     "Expired" : "Utgånget",
+    "Shared secret" : "Delad hemlighet",
     "Validate SSL certificate" : "Validera SSL-certifikat",
     "Delete this server" : "Ta bort denna server",
     "Status: Checking connection" : "Status: Kontrollerar anslutning",
@@ -439,7 +439,6 @@ OC.L10N.register(
     "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver bör eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
     "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Observera att samtal med fler än 4 deltagare utan extern signalserver kan uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
     "Don't warn about connectivity issues in calls with more than 4 participants" : "Varna inte om anslutningsproblem i samtal med fler än 4 deltagare",
-    "Shared secret" : "Delad hemlighet",
     "STUN server URL" : "STUN-serverwebbadress",
     "STUN servers" : "STUN-servrar",
     "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server används för att bestämma den offentliga IP-adressen av deltagare bakom en router.",
@@ -497,7 +496,7 @@ OC.L10N.register(
     "Conversation settings" : "Konversationsinställningar",
     "Chat notifications" : "Chatt-aviseringar",
     "Leave conversation" : "Lämna konversationen",
-    "Delete conversation" : "Radera konversationen",
+    "Delete conversation" : "Ta bort konversationen",
     "Remove from favorites" : "Ta bort från favoriter",
     "Add to favorites" : "Lägg till som favorit",
     "You: {lastMessage}" : "Du: {lastMessage}",
@@ -536,7 +535,7 @@ OC.L10N.register(
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du väntar för närvarande i lobbyn. Detta möte är planerat till {startTime}",
     "Camera" : "Kamera",
     "Reply" : "Svara",
-    "Remove" : "Radera",
+    "Remove" : "Ta bort",
     "[Unknown username]" : "[Okänt användarnamn]",
     "Today" : "Idag",
     "Yesterday" : "Igår",
@@ -608,6 +607,8 @@ OC.L10N.register(
     "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Webbläsaren du använder stöds inte av Nextcloud Talk. Använd den senaste versionen av Mozilla Firefox, Microsoft Edge, Google Chrome eller Apple Safari.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk uppdaterades, ladda om sidan igen",
+    "Do not disturb" : "Stör ej",
+    "Away" : "Iväg",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud är i underhållsläge, ladda om sidan igen",
     "Error while sharing file" : "Fel vid delning av fil",
     "Error while uploading file" : "Fel vid uppladdning av fil",
@@ -616,7 +617,7 @@ OC.L10N.register(
     "Failed to establish signaling connection. Retrying …" : "Det gick inte att upprätta signalanslutning. Försöker igen ...",
     "Default" : "Standard",
     "You seem to be talking while muted, please unmute yourself for others to hear you" : "Du verkar prata med avstängd mikrofon, sätt på mikrofonen för att andra ska höra dig",
-    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Det gick inte att upprätta en anslutning med minst en deltagare. En TURN-server kan behövas för ditt scenario. Be din administratör att sätta upp en efter {linkstart}den här dokumentationen{linkend}.",
+    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Det gick inte att upprätta en anslutning med minst en deltagare. En TURN-server kan behövas för ditt scenario. Be din administratör att ställa in en med hjälp av {linkstart}den här dokumentationen{linkend}.",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Det tar längre tid än väntat. Har mediarättigheter redan beviljats (eller avvisats)? Om ja, starta om din webbläsare, eftersom ljud och video misslyckas",
     "Access to microphone & camera is only possible with HTTPS" : "Åtkomst till mikrofon och kamera är endast möjligt via HTTPS",
     "Please move your setup to HTTPS" : "Vänligen flytta din inställning till HTTPS",
@@ -635,6 +636,7 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Gå med i konversationer när som helst, var som helst, på alla enheter.",
     "Android app" : "Android-app",
     "iOS app" : " iOS-app",
+    "{user} wants to talk with you" : "{user} vill prata med dig",
     "No other people in this call" : "Inga andra personer i detta samtal",
     "Your screen" : "Din skärm",
     "Contacts" : "Kontakter",
