@@ -1,10 +1,20 @@
 OC.L10N.register(
     "spreed",
     {
+    "a conversation" : "交談",
+    "(Duration %s)" : "(已歷時 %s)",
+    "You attended a call with {user1}" : "您加入了與{user1}之間的通話",
+    "_%n guest_::_%n guests_" : ["%n位訪客"],
+    "You attended a call with {user1} and {user2}" : "您加入了與{user1}及{user2}之間的通話",
+    "You attended a call with {user1}, {user2} and {user3}" : "您加入了與{user1},{user2}及{user3}之間的通話",
+    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "您加入了與{user1},{user2},{user3}及{user4}之間的通話",
+    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "您加入了與{user1},{user2},{user3},{user4}及{user5}之間的通話",
+    "_%n other_::_%n others_" : ["及另外%n位其他人"],
+    "{actor} invited you to {call}" : "{actor} 要請你加入{call}",
     "Talk" : "交談",
     "Guest" : "訪客",
     "You created the conversation" : "你建立了對話",
-    "You started a call" : "您打了一通電話",
+    "You started a call" : "您發起了一通話",
     "You left the call" : "你離開了通話",
     "Join call" : "加入通話",
     "Open settings" : "開啟設定",
@@ -253,7 +263,6 @@ OC.L10N.register(
     "Mute audio (m)" : "靜音 (m)",
     "Mute audio" : "靜音",
     "Disable video" : "停用視訊",
-    "Back" : "返回",
     "You" : "您",
     "Favorite" : "我的最愛",
     "Leave conversation" : "離開對話",
@@ -265,6 +274,7 @@ OC.L10N.register(
     "Settings" : "設定",
     "Create a new group conversation" : "建立新群組對話",
     "Password protect" : "密碼防護",
+    "Back" : "返回",
     "Close" : "關閉",
     "Conversation name" : "對話名稱",
     "Allow guests to join via link " : "允許訪客透過連結加入",
@@ -300,6 +310,7 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "離開全螢幕 (f)",
     "Fullscreen (f)" : "全螢幕 (f)",
     "Grid view" : "網格檢視",
+    "Send" : "傳送",
     "Say hi to your friends and colleagues!" : "跟大家打招呼",
     "Start a conversation" : "新對話",
     "Join a conversation or start a new one" : "加入一個對話或者開一個新的",
@@ -307,35 +318,14 @@ OC.L10N.register(
     "The password is wrong. Try again." : "密碼錯誤，請重試",
     "Android app" : "安卓應用",
     "iOS app" : "蘋果應用",
-    "Enter name for a new conversation" : "輸入新對話名稱",
-    "New conversation …" : "新對話",
+    "Contacts" : "聯絡人",
+    "Search conversations or contacts" : "搜尋對話或聯絡人",
+    "[Unknown user name]" : "[未知的使用者名稱]",
+    "Guests" : "訪客",
     "Projects" : "專案項目",
-    "Copy" : "複製",
-    "Copied!" : "已複製！",
-    "Not supported!" : "不支援！",
-    "Press ⌘-C to copy." : "按下 ⌘-C 來複製",
-    "Press Ctrl-C to copy." : "按下 Ctrl-C 複製",
-    "Room name can not be empty" : "名稱不能空白",
+    "Limit app usage to groups." : "限制群組的使用率:",
     "Password required" : "請輸入密碼",
     "Cancel" : "取消",
-    "Submit" : "送出",
-    "Guests" : "訪客",
-    "Change password" : "變更密碼",
-    "Set password" : "設定密碼",
-    "Rename" : "重新命名",
-    "Conversation with {name}" : "和 {name} 的談話",
-    "No messages yet, start the conversation!" : "尚無訊息，開始對話！",
-    "New message …" : "新訊息 ...",
-    "Send" : "傳送",
-    "Share" : "分享",
-    "[Unknown user name]" : "[未知的使用者名稱]",
-    "Error while sharing" : "分享時發生錯誤",
-    "Waiting for {participantName} to join the call …" : "等待{participantName}加入通話...",
-    "Share screen" : "分享螢幕",
-    "Screensharing is not supported by your browser." : "您的瀏覽器並不支援螢幕分享",
-    "Favorited" : "已加入最愛",
-    "Limit app usage to groups." : "限制群組的使用率:",
-    "Contacts" : "聯絡人",
-    "Search conversations or contacts" : "搜尋對話或聯絡人"
+    "Submit" : "送出"
 },
 "nplurals=1; plural=0;");
