@@ -26,6 +26,7 @@ namespace OCA\Talk\Chat\Command;
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Events\CommandEvent;
 use OCA\Talk\Model\Command;
+use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Service\CommandService;
 use OCP\AppFramework\Db\DoesNotExistException;
@@ -69,7 +70,23 @@ class Executor {
 		$this->l = $l;
 	}
 
-	public function exec(Room $room, IComment $message, Command $command, string $arguments): void {
+	public function isCommandAvailableForParticipant(Command $command, Participant $participant): bool {
+		if ($command->getEnabled() === Command::ENABLED_OFF) {
+			return false;
+		}
+
+		if ($command->getEnabled() === Command::ENABLED_MODERATOR && !$participant->hasModeratorPermissions()) {
+			return false;
+		}
+
+		if ($command->getEnabled() === Command::ENABLED_USERS && $participant->isGuest()) {
+			return false;
+		}
+
+		return true;
+	}
+
+	public function exec(Room $room, IComment $message, Command $command, string $arguments, Participant $participant): void {
 		try {
 			$command = $this->commandService->resolveAlias($command);
 		} catch (DoesNotExistException $e) {
@@ -85,7 +102,7 @@ class Executor {
 		}
 
 		if ($command->getApp() === '' && $command->getCommand() === 'help') {
-			$output = $this->execHelp($room, $message, $arguments);
+			$output = $this->execHelp($room, $message, $arguments, $participant);
 		} elseif ($command->getApp() !== '') {
 			$output = $this->execApp($room, $message, $command, $arguments);
 		} else {
@@ -102,7 +119,7 @@ class Executor {
 		$message->setVerb('command');
 	}
 
-	protected function execHelp(Room $room, IComment $message, string $arguments): string {
+	protected function execHelp(Room $room, IComment $message, string $arguments, Participant $participant): string {
 		if ($arguments !== '' && $arguments !== 'help') {
 			return $this->execHelpSingleCommand($room, $message, $arguments);
 		}
@@ -114,7 +131,8 @@ class Executor {
 			if ($command->getApp() !== '') {
 				$response = $this->execHelpSingleCommand($room, $message, $command->getApp() . ' ' . $command->getCommand());
 			} else {
-				if ($command->getCommand() === 'help' || strpos($command->getScript(),'alias:') !== false) {
+				if ($command->getCommand() === 'help' || strpos($command->getScript(),'alias:') !== false ||
+						!$this->isCommandAvailableForParticipant($command, $participant)) {
 					continue;
 				}
 				$response = $this->execHelpSingleCommand($room, $message, $command->getCommand());
