@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 /**
  * @copyright Copyright (c) 2018 Joas Schilling <coding@schilljs.com>
@@ -53,24 +54,25 @@ class ConversationProvider implements IProvider {
 
 	public function getResourceRichObject(IResource $resource): array {
 		try {
-			$room = $this->manager->getRoomByToken($resource->getId());
 			$user = $this->userSession->getUser();
+			$userId = $user instanceof IUser ? $user->getUID() : '';
+			$room = $this->manager->getRoomByToken($resource->getId(), $userId);
 
 			$iconURL = $this->urlGenerator->getAbsoluteURL($this->urlGenerator->imagePath('spreed', 'app-dark.svg'));
 			/**
 			 * Disabled for now, because it would show a square avatar
-			if ($room->getType() === Room::ONE_TO_ONE_CALL) {
-				$iconURL = $this->urlGenerator->linkToRouteAbsolute('core.avatar.getAvatar', ['userId' => 'admin', 'size' => 32]);
-			}
+			 * if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+			 * $iconURL = $this->urlGenerator->linkToRouteAbsolute('core.avatar.getAvatar', ['userId' => 'admin', 'size' => 32]);
+			 * }
 			 */
 
 			return [
 				'type' => 'room',
 				'id' => $resource->getId(),
-				'name' => $room->getDisplayName($user instanceof IUser ? $user->getUID() : ''),
+				'name' => $room->getDisplayName($userId),
 				'call-type' => $this->getRoomType($room),
 				'iconUrl' => $iconURL,
-				'link' => $this->urlGenerator->linkToRouteAbsolute('spreed.pagecontroller.showCall', ['token' => $room->getToken()])
+				'link' => $this->urlGenerator->linkToRouteAbsolute('spreed.Page.showCall', ['token' => $room->getToken()])
 			];
 		} catch (RoomNotFoundException $e) {
 			throw new ResourceException('Conversation not found');
