@@ -48,12 +48,12 @@ use OCP\Files\IRootFolder;
 use OCP\ICacheFactory;
 use OCP\IConfig;
 use OCP\IInitialStateService;
-use OCP\ILogger;
 use OCP\IRequest;
 use OCP\IURLGenerator;
 use OCP\IUser;
 use OCP\IUserSession;
 use OCP\Notification\IManager as INotificationManager;
+use Psr\Log\LoggerInterface;
 
 class PageController extends Controller {
 	use TInitialState;
@@ -68,7 +68,7 @@ class PageController extends Controller {
 	private $talkSession;
 	/** @var IUserSession */
 	private $userSession;
-	/** @var ILogger */
+	/** @var LoggerInterface */
 	private $logger;
 	/** @var Manager */
 	private $manager;
@@ -88,7 +88,7 @@ class PageController extends Controller {
 								TalkSession $session,
 								IUserSession $userSession,
 								?string $UserId,
-								ILogger $logger,
+								LoggerInterface $logger,
 								Manager $manager,
 								IURLGenerator $url,
 								INotificationManager $notificationManager,
@@ -185,8 +185,9 @@ class PageController extends Controller {
 		if ($token !== '') {
 			$room = null;
 			try {
-				$room = $this->manager->getRoomByToken($token);
+				$room = $this->manager->getRoomByToken($token, $this->userId);
 				$notification = $this->notificationManager->createNotification();
+				$shouldFlush = $this->notificationManager->defer();
 				try {
 					$notification->setApp('spreed')
 						->setUser($this->userId)
@@ -195,7 +196,11 @@ class PageController extends Controller {
 					$notification->setObject('call', $room->getToken());
 					$this->notificationManager->markProcessed($notification);
 				} catch (\InvalidArgumentException $e) {
-					$this->logger->logException($e, ['app' => 'spreed']);
+					$this->logger->error($e->getMessage(), ['exception' => $e]);
+				}
+
+				if ($shouldFlush) {
+					$this->notificationManager->flush();
 				}
 
 				// If the room is not a public room, check if the user is in the participants
@@ -237,7 +242,8 @@ class PageController extends Controller {
 			}
 		} else {
 			$response = $this->api->createRoom(Room::ONE_TO_ONE_CALL, $callUser);
-			if ($response->getStatus() !== Http::STATUS_NOT_FOUND) {
+			if ($response->getStatus() === Http::STATUS_OK
+				|| $response->getStatus() === Http::STATUS_CREATED) {
 				$data = $response->getData();
 				return $this->redirectToConversation($data['token']);
 			}
