@@ -1097,7 +1097,10 @@ class RoomController extends AEnvironmentAwareController {
 				&& $room->getNumberOfModerators() === 1) {
 				return new DataResponse([], Http::STATUS_BAD_REQUEST);
 			}
-		} elseif ($room->getType() !== Room::CHANGELOG_CONVERSATION &&
+		}
+
+		if ($room->getType() !== Room::CHANGELOG_CONVERSATION &&
+			$room->getObjectType() !== 'file' &&
 			$room->getNumberOfParticipants() === 1) {
 			$room->deleteRoom();
 			return new DataResponse();
