@@ -102,6 +102,11 @@ trait TInitialState {
 			'talk', 'attachment_folder',
 			$attachmentFolder
 		);
+
+		$this->initialStateService->provideInitialState(
+			'talk', 'enable_matterbridge',
+			$this->serverConfig->getAppValue('spreed', 'enable_matterbridge', '0') === '1'
+		);
 	}
 
 	protected function publishInitialStateForGuest(): void {
@@ -121,5 +126,10 @@ trait TInitialState {
 			'talk', 'attachment_folder',
 			''
 		);
+
+		$this->initialStateService->provideInitialState(
+			'talk', 'enable_matterbridge',
+			false
+		);
 	}
 }
